@@ -36,8 +36,9 @@ from modin.pandas.test.utils import (
     create_test_dfs,
     eval_general,
 )
+from modin.config import NPartitions
 
-pd.DEFAULT_NPARTITIONS = 4
+NPartitions.put(4)
 
 # Force matplotlib to not use any Xwindows backend.
 matplotlib.use("Agg")
@@ -870,6 +871,42 @@ def test_reorder_levels():
     )
 
 
+def test_reindex_multiindex():
+    data1, data2 = np.random.randint(1, 20, (5, 5)), np.random.randint(10, 25, 6)
+    index = np.array(["AUD", "BRL", "CAD", "EUR", "INR"])
+    modin_midx = pd.MultiIndex.from_product(
+        [["Bank_1", "Bank_2"], ["AUD", "CAD", "EUR"]], names=["Bank", "Curency"]
+    )
+    pandas_midx = pandas.MultiIndex.from_product(
+        [["Bank_1", "Bank_2"], ["AUD", "CAD", "EUR"]], names=["Bank", "Curency"]
+    )
+    modin_df1, modin_df2 = (
+        pd.DataFrame(data=data1, index=index, columns=index),
+        pd.DataFrame(data2, modin_midx),
+    )
+    pandas_df1, pandas_df2 = (
+        pandas.DataFrame(data=data1, index=index, columns=index),
+        pandas.DataFrame(data2, pandas_midx),
+    )
+    modin_df2.columns, pandas_df2.columns = ["Notional"], ["Notional"]
+    md_midx = pd.MultiIndex.from_product([modin_df2.index.levels[0], modin_df1.index])
+    pd_midx = pandas.MultiIndex.from_product(
+        [pandas_df2.index.levels[0], pandas_df1.index]
+    )
+    # reindex without axis, index, or columns
+    modin_result = modin_df1.reindex(md_midx, fill_value=0)
+    pandas_result = pandas_df1.reindex(pd_midx, fill_value=0)
+    df_equals(modin_result, pandas_result)
+    # reindex with only axis
+    modin_result = modin_df1.reindex(md_midx, fill_value=0, axis=0)
+    pandas_result = pandas_df1.reindex(pd_midx, fill_value=0, axis=0)
+    df_equals(modin_result, pandas_result)
+    # reindex with axis and level
+    modin_result = modin_df1.reindex(md_midx, fill_value=0, axis=0, level=0)
+    pandas_result = pandas_df1.reindex(pd_midx, fill_value=0, axis=0, level=0)
+    df_equals(modin_result, pandas_result)
+
+
 @pytest.mark.parametrize("data", test_data_values, ids=test_data_keys)
 def test_reset_index(data):
     modin_df = pd.DataFrame(data)
@@ -1178,19 +1215,16 @@ def test___setitem__(data):
         df_equals(modin_df, pandas_df)
         assert isinstance(modin_df["new_col"][0], type(pandas_df["new_col"][0]))
 
+    modin_df[1:5] = 10
+    pandas_df[1:5] = 10
+    df_equals(modin_df, pandas_df)
+
     # Transpose test
     modin_df = pd.DataFrame(data).T
     pandas_df = pandas.DataFrame(data).T
 
-    # We default to pandas on non-string column names
-    if not all(isinstance(c, str) for c in modin_df.columns):
-        with pytest.warns(UserWarning):
-            modin_df[modin_df.columns[0]] = 0
-    else:
-        modin_df[modin_df.columns[0]] = 0
-
+    modin_df[modin_df.columns[0]] = 0
     pandas_df[pandas_df.columns[0]] = 0
-
     df_equals(modin_df, pandas_df)
 
     modin_df.columns = [str(i) for i in modin_df.columns]
@@ -1203,9 +1237,14 @@ def test___setitem__(data):
 
     modin_df[modin_df.columns[0]][modin_df.index[0]] = 12345
     pandas_df[pandas_df.columns[0]][pandas_df.index[0]] = 12345
-
     df_equals(modin_df, pandas_df)
 
+    modin_df[1:5] = 10
+    pandas_df[1:5] = 10
+    df_equals(modin_df, pandas_df)
+
+
+def test___setitem__partitions_aligning():
     # from issue #2390
     modin_df = pd.DataFrame({"a": [1, 2, 3]})
     pandas_df = pandas.DataFrame({"a": [1, 2, 3]})
@@ -1222,12 +1261,15 @@ def test___setitem__(data):
     # Setting new column
     pd_df["b"] = pandas.Series(np.arange(4))
     md_df["b"] = pd.Series(np.arange(4))
-
     df_equals(md_df, pd_df)
+
     # Setting existing column
     pd_df["b"] = pandas.Series(np.arange(4))
     md_df["b"] = pd.Series(np.arange(4))
+    df_equals(md_df, pd_df)
 
+    pd_df["a"] = pandas.Series(np.arange(4))
+    md_df["a"] = pd.Series(np.arange(4))
     df_equals(md_df, pd_df)
 
 
@@ -1273,19 +1315,16 @@ def test___setitem__mask():
     "data",
     [
         {},
-        pytest.param(
-            {"id": [], "max_speed": [], "health": []},
-            marks=pytest.mark.xfail(
-                reason="Throws an exception because generally assigning Series or other objects of length different from DataFrame does not work right now"
-            ),
-        ),
+        {"id": [], "max_speed": [], "health": []},
+        {"id": [1], "max_speed": [2], "health": [3]},
+        {"id": [4, 40, 400], "max_speed": [111, 222, 333], "health": [33, 22, 11]},
     ],
-    ids=["empty", "empty_columns"],
+    ids=["empty_frame", "empty_cols", "1_length_cols", "2_length_cols"],
 )
 @pytest.mark.parametrize(
     "value",
-    [np.array(["one", "two"]), [11, 22]],
-    ids=["ndarray", "list"],
+    [[11, 22], [11, 22, 33]],
+    ids=["2_length_val", "3_length_val"],
 )
 @pytest.mark.parametrize("convert_to_series", [False, True])
 @pytest.mark.parametrize("new_col_id", [123, "new_col"], ids=["integer", "string"])
@@ -1293,9 +1332,19 @@ def test_setitem_on_empty_df(data, value, convert_to_series, new_col_id):
     pandas_df = pandas.DataFrame(data)
     modin_df = pd.DataFrame(data)
 
-    pandas_df[new_col_id] = pandas.Series(value) if convert_to_series else value
-    modin_df[new_col_id] = pd.Series(value) if convert_to_series else value
-    df_equals(modin_df, pandas_df)
+    def applyier(df):
+        if convert_to_series:
+            converted_value = (
+                pandas.Series(value)
+                if isinstance(df, pandas.DataFrame)
+                else pd.Series(value)
+            )
+        else:
+            converted_value = value
+        df[new_col_id] = converted_value
+        return df
+
+    eval_general(modin_df, pandas_df, applyier)
 
 
 @pytest.mark.parametrize("data", test_data_values, ids=test_data_keys)
@@ -1325,3 +1374,17 @@ def test_index_order():
             getattr(df_modin, func)(level=0).index,
             getattr(df_pandas, func)(level=0).index,
         )
+
+
+@pytest.mark.parametrize("data", test_data_values, ids=test_data_keys)
+@pytest.mark.parametrize("sortorder", [0, 3, 5])
+def test_multiindex_from_frame(data, sortorder):
+    modin_df, pandas_df = create_test_dfs(data)
+
+    def call_from_frame(df):
+        if type(df).__module__.startswith("pandas"):
+            return pandas.MultiIndex.from_frame(df, sortorder)
+        else:
+            return pd.MultiIndex.from_frame(df, sortorder)
+
+    eval_general(modin_df, pandas_df, call_from_frame, comparator=assert_index_equal)
